<?php
/*
Plugin Name: User Login XML
Description: Allow users to create an account and login to your website. Protects pages.
Version: 1.0
Author: Mike Henken
Author URI: http://profileyourcity.com
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

//Path To website.xml File
$thisfilew=GSDATAOTHERPATH .'website.xml';

//Path To User Login plugin Settings File (user-login.xml)
$pluginfile=GSDATAOTHERPATH .'user-login.xml';

//Define User Login Plugin's plugins Folder (plugins/user-login/)
define('USERLOGINPATH', GSPLUGINPATH . 'user-login/');

//Define The User Data Storage Folder (data/site-users)
define('SITEUSERSPATH', GSDATAPATH . 'site-users/');

# register plugin
register_plugin(
	$thisfile, 													# ID of plugin, should be filename minus php
	'User Login XML', 									# Title of plugin
	'1.0', 															# Version of plugin
	'Mike Henken',											# Author of plugin
	'http://profileyourcity.com', 			# Author URL
	'Allow users to create an account and login to your website. Protects pages.', 	# Plugin Description
	'settings', 													# Page type of plugin
	'user_login_admin'  										# Function that displays content
);

# hooks
//Add Tab To Sitebar In Settings Pages
add_action('settings-sidebar','createSideMenu',array($thisfile,'User Login Settings')); 

//Launch Function 'user_login_check' before the template is loaded on the front-end
add_action('index-pretemplate','user_login_check');

//Filter Out The Content (Checks To See If Page Is Protected Or Not)
add_filter('content','perm_check');

//Adds 'Members Only' Check Box In edit.php
add_action('edit-extras','user_login_edit');

//Saves 'Members Only' checkbox selection when a page is saved
add_action('changedata-save','user_login_save');


# Get The Website URL From data/other/website.xml
if (file_exists($thisfilew)) {
	$website_settings = getXML($thisfilew);
	global $site_url;
	$site_url = $website_settings->SITEURL;
} else {
	$site_url = '';
}

//Define The CSS And Protected Message - Make Global Variables
if (file_exists($pluginfile)) {
	$user_login_settings = getXML($pluginfile);
	global $login_container_css;
	$login_container_css = $user_login_settings->logincontainer;
	global $welcome_box_css;
	$welcome_box_css = $user_login_settings->welcomebox;
	global $register_box_css;
	$register_box_css = $user_login_settings->registerbox;
	global $protected_message;
	$protected_message = $user_login_settings->protectedmessage;
}
//If Plugin XML File Is Not Created - The Following CSS Should Be Used - (Voided If File Already Exists)
 else {
 //CSS For The Login Container - (Holds The Username/Password Fields & Submit Button)
	global $login_container_css;
	$login_container_css = '<style>
		
		/* User Register Link */
		.user_login_register {
		
		}
		
		/* Login Box Container */
		#login_box {
			margin:10px;margin-left:0px;width:100%;
		}
		
		/* Login Form */
		#loginform {
		
		}
		
		/* Login Label */
		.user_login_label {
			font-size:18px;
			float:left;
			padding-right:10px;
		}
		
		/* Login Username Field */
		.user_login_username {
			height:17px;
			padding:2px;
			border:1px solid black;
			width:75px;
			float:left;
		}
		
		/* Login Password Field */
		.user_login_password {
			height:17px;
			padding:2px;
			border:1px solid black;
			width:75px;
			float:left;
			margin-left:8px;
		}
		
		/* Login Submit Button */
		.user_login_submit {
			float:left;
			padding:3px;
		}
		</style>';
		
//Welcome Box CSS -  Holds Welcome Message For User
	global $welcome_box_css;
	$welcome_box_css = '<style>
               /* Span Tag Around "Welcome" Text */
		.user-login-welcome-label {
		font-size:17px;font-weight:bold;
		}
               
               /* Logout Link */
		.user-login-logout-link {
		
		}
                
                 .user_login_welcome_box_container {
                               font-size:16px;width:100%;
                  }

</style>';

//Register Box CSS - CSS For All Fields/titles/labels For Register Box
	global $register_box_css;
	$register_box_css = '			<style>
			.user-login-register-title {
				font-size:16px;font-weight:bold;
			}
			
			/* Register Form Labels */
			#registerform label{
				font-size:14px;font-weight:bold;
			}
			#registerform input{
				font-size:14px;font-weight:bold;width:100px;float:right;
			}
			#registerform input[type=submit]{
				float:left;
			}
			
			</style>';

//Protected Message - The Formatting/text For Protected Message - Can Be Changed Via CKEDITOR Through Plugin Admin Page
	global $protected_message;
	$protected_message = '<div style="width:100%;height:25px;clear:both;padding:20px;font-size:18px;">
	This Page Requires You To Be Logged In To View</div>
';
}

/*******
Function To:
Check If Page Is Protected Or Not. Then, Either Blocks Access Or Shows Content, Depending On If Logged In Or Not
*******/
function perm_check($content)
{
	global $protected_message;
	global $the_page_slug;
	//Get Current Page Slug And XML File
	$the_page_slug =  return_page_slug();
	$the_page_slug_xml = GSDATAPAGESPATH.$the_page_slug.'.xml';
	$page_data = getXML($the_page_slug_xml);
	
	//Check If Page Is For Members Only
	if($page_data->memberonly == "yes")
	{
		//If The Page Is For Members Only And The User Is Not Logged In Display protected Message
		if(!isset($_SESSION['LoggedIn']))
		{
			return $protected_message;
		}
		
		//If Page Is For Members Only And The User Is* Logged In - Display Normal Content
		elseif (isset($_SESSION['LoggedIn']))
		{
			return $content;
		}
	}	

	//If The Page Is NOT For Members Only - Display Normal Content
	elseif ($page_data->memberonly != "yes")
	{
		return $content;
	}
}

/*******
Function To: 
Proccess Admin User Login Settings
*******/
function user_login_admin()
{
if(isset($_POST['post-login-container']))
	{
		global $pluginfile;
		$login_container_data = safe_slash_html($_POST['post-login-container']);
		$welcome_box_data = safe_slash_html($_POST['post-welcome-box']);
		$protected_content_data = safe_slash_html($_POST['post-protected-message']);
		$register_box_data = safe_slash_html($_POST['post-register-box']);
		
			# create xml file
			if (file_exists($pluginfile)) { unlink($pluginfile); }	
			$xml = new SimpleXMLElement('<item></item>');
			$xml->addChild('logincontainer', $login_container_data);
			$xml->addChild('welcomebox', $welcome_box_data);
			$xml->addChild('protectedmessage', $protected_content_data);
			$xml->addChild('registerbox', $register_box_data);
			if (! XMLsave($xml, $pluginfile) ) {
				$error = i18n_r('CHMOD_ERROR');
			}
			if (!$error) {
			$success = i18n_r('ER_SETTINGS_UPD').'. <a href="load.php?id=user_login&success=User Login Settings Saved.'.get_nonce("undo").'">'.i18n_r('UNDO').'</a>';
		}
	}
	user_login_admin_form();
}

/*******
Function To: 
Show Admin User Login Settings Form
*******/
function user_login_admin_form()
{
	global $site_url;
	global $login_container_css;
	global $welcome_box_css;
	global $register_box_css;
?>

<h2>User Settings</h2>
<form method="post" action="load.php?id=user_login">

<h3>Edit Login Container CSS</h3>
<?php echo'<textarea name="post-login-container" style="width:625px;height:300px;">'.$login_container_css.'</textarea>'; ?>
<br/><br/>
<h3>Edit Welcome Box CSS</h3>
<?php echo'<textarea name="post-welcome-box" style="width:625px;height:300px;">'.$welcome_box_css.'</textarea>'; ?>
<br/><br/>
<h3>Edit Register Box CSS</h3>
<?php echo'<textarea name="post-register-box" style="width:625px;height:300px;">'.$register_box_css.'</textarea>'; ?>
<?php include(USERLOGINPATH . 'ckeditor.php'); ?>
<br/><br/>
<h3>Edit Protected Message</h3>
<textarea name="post-protected-message"><?php global $protected_message; echo $protected_message; ?></textarea>
<?php include(USERLOGINPATH . 'ckeditor.php'); ?>
<input type="submit" class="submit" value="Submit" />
</form>
<?php
}

/*******
Function To: 
Displays Login Box On Front-End Of Website
*******/
function show_login_box()
{
	global $the_page_slug;
	global $site_url;
	global $login_container_css;
	global $logged_in_message;

	//If The User Is Not Logged In - Display Login Box - If They Are Logged In, Display Nothing
	if(!isset($_SESSION['LoggedIn']))
	{	
		//HTML Code For Login Container
		$login_container = '
		<div id="login_box" style="">
		<form method="post" action="'.$site_url.'/'.$the_page_slug.'" name="loginform" id="loginform">
				<label for="username" class="user_login_label">Login: </label>
				<input type="text" name="username" style="" class="user_login_username" value="Username.." onFocus="if(this.value == \'Username..\') {this.value = \'\';}" onBlur="if (this.value == \'\') {this.value = \'Username..\';}" />
				<input type="text" name="password" class="user_login_password" style="" value="Password.." onFocus="if(this.value == \'Password..\') {this.value = \'\';}" onBlur="if (this.value == \'\') {this.value = \'Password..\';}" />
				<input type="submit" style="" class="user_login_submit" value="Submit"/>
				<input type="hidden" name="login-form" value="login" />
		</form>
				<div style="clear:both"></div></div>';
			
		echo $login_container_css.$login_container.$logged_in_message;
	}
}

/*******
Function To: 
Show Welcome Message If User Is Logged In - If Not Logged In, Display nothing
*******/
function welcome_message_login()
{
	global $welcome_box_css;
	global $site_url;
	global $the_page_slug;
	
	if(isset($_SESSION['LoggedIn']))
	{
		//Get Username Of Logged In User
		$the_username = $_SESSION['Username'];
		
		//Display Welcome Message
		$welcome_box = '<div class="user_login_welcome_box_container"><span class=\"user-login-welcome-label\">Welcome: </span>'.$the_username.'</div>';
		
		//Display Logout Link
		$logout_link = " <a href=\"$site_url/$the_page_slug/?logout=yes\" class=\"user-login-logout-link\">Logout</a>";
		echo $welcome_box_css.$welcome_box.$logout_link ;
	}
}

/*******
Function To: 
Check If User Is Logged In - Also Starts Session And Connects To Database
*******/
function user_login_check()
{
	global $site_url;
	global $logged_in_message;
	//Check If User Session Is Started - If It IS NOT* Started, Then Start Session
	if(!isset($_SESSION))
	{
		session_start();
	}
	
	$the_page_slug =  return_page_slug();
	
	//Check If Logged In - Define Username
	if(!empty($_SESSION['LoggedIn']) && !empty($_SESSION['Username']))
	{
		//If Logged In The $logged_in Variable = true
		$logged_in = true;
		
		//Get Username Of Logged In Visitor
		$the_username = $_SESSION['Username'];

	}

	//If Not Logged In But USername And Password Have Been Posted
	elseif(!empty($_POST['username']) && !empty($_POST['password']) && !empty($_POST['login-form']))
	{

	//Set Posted Username And Password Variable
		$username = strtolower($_POST['username']);
		$password = $_POST['password'];
		$dir = GSDATAPATH . 'site-users/' . $username . ".xml";
		
		//Check If User File EXists (Get Password From File)
		if(file_exists($dir))
		{
			$xmll = simplexml_load_file($dir) or die("Unable to load XML file!");
			$user_pass = $xmll->Password;
		}
		else
		{
			$user_pass = "";
		}
			//Check XML File Password.. If Correct, Log User In And Redirect Back To Page
			if(md5($password) == $user_pass)
			{
				$_SESSION['Username'] = $username;
				$_SESSION['LoggedIn'] = 1;
				$logged_in = true;
			}
			
			//If Login Credentials were wrong.. Do Not Log Visitor In And Return wrong information message
			else
			{
				$logged_in_message =  "<p>Sorry, your account could not be found. Please try again.</p>";
				$logged_in = false;
			}
		
	}
	/* 
	If Logout Link Is Clicked:
	Log Client Out (End Session) 
	*/
	if(isset($_GET['logout']))
	{
		if(!empty($_SESSION['LoggedIn']) && !empty($_SESSION['Username']))
		{
			$_SESSION = array(); session_destroy();
			//$welcome_box = $login_container;
		}
	}
}


/*******
Function To: 
Register Form And Processing Code - Display's And Processes Register Form
*******/
function user_login_register()
{
	global $register_box_css;
	global $site_url;
	global $the_page_slug;
	
	//If User Is Not Logged In
	if(!isset($_SESSION['LoggedIn']))
	{
		//If Register Form Was Submitted
		if(!empty($_POST['username']) && !empty($_POST['password']) && !empty($_POST['email']) && !empty($_POST['register-form']))
		{
			//Define Username, Email, And Password The User Chose
			$username = strtolower($_POST['username']);
			$password = md5($_POST['password']);
			$email = $_POST['email'];
			$dir = GSDATAPATH . 'site-users/' . $username . ".xml";

			//If Username Is taken Notify User To Choose A Differant One
			 if(file_exists($dir))
			 {
				echo "<h1>Error</h1>";
				echo "<p>Sorry, that username is taken. Please go back and try again.</p>";
			 }
			 
			 //If username is not taken - Create Account And Log User In
			 else
			{
				if(!file_exists(SITEUSERSPATH))
				{
					mkdir(SITEUSERSPATH);
				}
				else
				{
				}
				$xmll = new SimpleXMLElement('<item></item>');
				$xmll->addChild('Username', $username);
				$xmll->addChild('Password', $password);
				$xmll->addChild('EmailAddress', $email);
				if (XMLsave($xmll, SITEUSERSPATH . $username . '.xml')) {
					echo "<h1>Success</h1>";
					echo "<p>Your account was successfully created..</p>";

				}
				else 
				{
				//If Account Was Created - Display Success Message
					echo "<h1>Error</h1>";
					echo "<p>Sorry, your registration failed. Please go back and try again.</p>";
				}
			}
		}
		else
		{
			//Display Register Box
			echo $register_box_css.'
			<p class="user-login-register-title">Register</p>
			<form method="post" action="'.$site_url.'/'.$the_page_slug.'/?register=yes" name="registerform" id="registerform">
				<fieldset>
					<p><label for="username">Username:</label><input type="text" name="username" id="username" /></p>
					<p><label for="password">Password:</label><input type="password" name="password" id="password" /></p>
					<p><label for="email">Email Address:</label><input type="text" name="email" id="email" /></p>
					<input type="hidden" name="register-form" value="yes" />
					<p><input type="submit" name="register" id="register" value="Register" /></p>
				</fieldset>
				</form>';
		}
	}
}

//Displays members Only Checkbox In edit.php
function user_login_edit()
{
//Check If Checkbox For Current Page Editing Is Already Checked
	$current_page_edit = $_GET['id'];
	$the_page_slug_xml = GSDATAPAGESPATH.$current_page_edit.'.xml';
	$page_data = getXML($the_page_slug_xml);
	
	//Check If Page Is For Members Only
	if($page_data->memberonly == "yes")
	{
		$member_checkbox = "checked";
	}
	else
	{
		$member_checkbox = "";
	}
	echo '
	<div style="width:95px;float:left;margin-bottom:20px;"> 
	<label for="post-template">Members Only:</label> 
	<input type="checkbox" value="yes" name="member-only" style="float:left;padding-top:5px;" '.$member_checkbox.'/>
	</div> 
	';
}

//Saves Value Of Checkbox in function - user_login_edit()
function user_login_save()
{
	global $xml; // SimpleXML to save to
		  if(isset($_POST['member-only']))
		  { 
			  $node = $xml->addChild(strtolower('memberonly'))->addCData(stripslashes($_POST['member-only']));	
		  }
}
